@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -22,60 +22,59 @@ import java.io.File;
 import java.io.FileReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
-import java.text.ParseException;
+import java.util.Arrays;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Map;
 
-import junit.framework.TestCase;
-
+import org.apache.ivy.TestHelper;
 import org.apache.ivy.core.module.descriptor.DependencyDescriptor;
 import org.apache.ivy.core.module.descriptor.ModuleDescriptor;
 import org.apache.ivy.core.module.id.ModuleRevisionId;
 import org.apache.ivy.core.settings.IvySettings;
 import org.apache.ivy.plugins.parser.xml.XmlModuleDescriptorParser;
 import org.apache.ivy.util.FileUtil;
+
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.Delete;
 
-public class IvyDeliverTest extends TestCase {
-    private File cache;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
+public class IvyDeliverTest {
 
     private IvyDeliver deliver;
 
     private Project project;
 
-    protected void setUp() throws Exception {
+    @Before
+    public void setUp() {
         cleanTestDir();
+        cleanRetrieveDir();
         cleanRep();
-        createCache();
-        project = new Project();
+        TestHelper.createCache();
+        project = TestHelper.newProject();
         project.init();
         project.setProperty("ivy.settings.file", "test/repositories/ivysettings.xml");
         project.setProperty("build", "build/test/deliver");
 
         deliver = new IvyDeliver();
         deliver.setProject(project);
-        System.setProperty("ivy.cache.dir", cache.getAbsolutePath());
+        System.setProperty("ivy.cache.dir", TestHelper.cache.getAbsolutePath());
     }
 
-    private void createCache() {
-        cache = new File("build/cache");
-        cache.mkdirs();
-    }
-
-    protected void tearDown() throws Exception {
-        cleanCache();
+    @After
+    public void tearDown() {
+        TestHelper.cleanCache();
         cleanTestDir();
+        cleanRetrieveDir();
         cleanRep();
     }
 
-    private void cleanCache() {
-        Delete del = new Delete();
-        del.setProject(new Project());
-        del.setDir(cache);
-        del.execute();
-    }
-
     private void cleanTestDir() {
         Delete del = new Delete();
         del.setProject(new Project());
@@ -83,6 +82,13 @@ public class IvyDeliverTest extends TestCase {
         del.execute();
     }
 
+    private void cleanRetrieveDir() {
+        Delete del = new Delete();
+        del.setProject(new Project());
+        del.setDir(new File("build/test/retrieve"));
+        del.execute();
+    }
+
     private void cleanRep() {
         Delete del = new Delete();
         del.setProject(new Project());
@@ -90,9 +96,10 @@ public class IvyDeliverTest extends TestCase {
         del.execute();
     }
 
-    public void testMergeParent() throws IOException, ParseException {
-        //publish the parent descriptor first, so that it can be found while
-        //we are reading the child descriptor.
+   @Test
+    public void testMergeParent() throws IOException {
+        // publish the parent descriptor first, so that it can be found while
+        // we are reading the child descriptor.
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-multiconf.xml");
         IvyResolve res = new IvyResolve();
         res.setProject(project);
@@ -105,13 +112,14 @@ public class IvyDeliverTest extends TestCase {
         File art = new File("build/test/deliver/resolve-simple-1.0.jar");
         FileUtil.copy(new File("test/repositories/1/org1/mod1.1/jars/mod1.1-1.0.jar"), art, null);
         pubParent.execute();
-        
-        //resolve and deliver the child descriptor
-        project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-extends-multiconf.xml");
+
+        // resolve and deliver the child descriptor
+        project.setProperty("ivy.dep.file",
+            "test/java/org/apache/ivy/ant/ivy-extends-multiconf.xml");
         res = new IvyResolve();
         res.setProject(project);
         res.execute();
-        
+
         deliver.setPubrevision("1.2");
         deliver.setDeliverpattern("build/test/deliver/merge/ivy-[revision].xml");
         deliver.execute();
@@ -124,30 +132,27 @@ public class IvyDeliverTest extends TestCase {
         // we could do a better job of this with xmlunit
         int lineNo = 1;
 
-        BufferedReader merged = new BufferedReader(new FileReader(delivered));
-        BufferedReader expected = new BufferedReader(new InputStreamReader(getClass()
-            .getResourceAsStream("ivy-extends-merged.xml")));
-        try {
-            for (String mergeLine = merged.readLine(),
-                        expectedLine = expected.readLine(); 
-                 mergeLine != null && expectedLine != null; 
-                 mergeLine = merged.readLine(),
-                 expectedLine = expected.readLine()) {
-    
-                mergeLine = mergeLine.trim();
-                expectedLine = expectedLine.trim();
-    
-                if (!mergeLine.startsWith("<info"))
-                    assertEquals("published descriptor matches at line[" + lineNo + "]", expectedLine.trim(), mergeLine.trim());
-    
-                ++lineNo;
-            }
-        } finally {
-            merged.close();
-            expected.close();
-        }
+       try (BufferedReader merged = new BufferedReader(new FileReader(delivered));
+            BufferedReader expected = new BufferedReader(new InputStreamReader(getClass().getResourceAsStream("ivy-extends-merged.xml")))) {
+           String mergeLine = merged.readLine();
+           String expectedLine = expected.readLine();
+           while (mergeLine != null && expectedLine != null) {
+               mergeLine = mergeLine.trim();
+               expectedLine = expectedLine.trim();
+
+               if (!mergeLine.startsWith("<info")) {
+                   assertEquals("published descriptor matches at line[" + lineNo + "]",
+                           expectedLine.trim(), mergeLine.trim());
+               }
+
+               ++lineNo;
+               mergeLine = merged.readLine();
+               expectedLine = expected.readLine();
+           }
+       }
     }
-    
+
+    @Test
     public void testSimple() throws Exception {
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-latest.xml");
         IvyResolve res = new IvyResolve();
@@ -162,17 +167,18 @@ public class IvyDeliverTest extends TestCase {
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), true);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"), md
-                .getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), true);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"),
+            md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(1, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2"), 
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2"),
             dds[0].getDependencyRevisionId());
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "latest.integration"), 
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "latest.integration"),
             dds[0].getDynamicConstraintDependencyRevisionId());
     }
 
+    @Test
     public void testNotGenerateRevConstraint() throws Exception {
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-latest.xml");
         IvyResolve res = new IvyResolve();
@@ -188,17 +194,18 @@ public class IvyDeliverTest extends TestCase {
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), true);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"), md
-                .getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), true);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"),
+            md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(1, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2"), 
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2"),
             dds[0].getDependencyRevisionId());
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2"), 
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2"),
             dds[0].getDynamicConstraintDependencyRevisionId());
     }
 
+    @Test
     public void testWithResolveId() throws Exception {
         IvyResolve resolve = new IvyResolve();
         resolve.setProject(project);
@@ -221,18 +228,19 @@ public class IvyDeliverTest extends TestCase {
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), true);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-simple", "1.2"), md
-                .getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), true);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-simple", "1.2"),
+            md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(1, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.0"), dds[0]
-                .getDependencyRevisionId());
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.0"),
+            dds[0].getDependencyRevisionId());
     }
 
+    @Test
     public void testWithResolveIdInAnotherBuild() throws Exception {
         // create a new build
-        Project other = new Project();
+        Project other = TestHelper.newProject();
         other.setProperty("ivy.settings.file", "test/repositories/ivysettings.xml");
         other.setProperty("build", "build/test/deliver");
 
@@ -258,15 +266,16 @@ public class IvyDeliverTest extends TestCase {
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), true);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-simple", "1.2"), md
-                .getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), true);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-simple", "1.2"),
+            md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(1, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.0"), dds[0]
-                .getDependencyRevisionId());
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.0"),
+            dds[0].getDependencyRevisionId());
     }
 
+    @Test
     public void testReplaceBranchInfo() throws Exception {
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-latest.xml");
         IvyResolve res = new IvyResolve();
@@ -282,13 +291,19 @@ public class IvyDeliverTest extends TestCase {
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), true);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "BRANCH1", "1.2"), 
-                        md.getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), true);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "BRANCH1", "1.2"),
+            md.getModuleRevisionId());
     }
 
+    /**
+     * Test case for IVY-404.
+     *
+     * @throws Exception if something goes wrong
+     * @see <a href="https://issues.apache.org/jira/browse/IVY-404">IVY-404</a>
+     */
+    @Test
     public void testWithBranch() throws Exception {
-        // test case for IVY-404
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-latest-branch.xml");
         IvyResolve res = new IvyResolve();
         res.setProject(project);
@@ -302,22 +317,24 @@ public class IvyDeliverTest extends TestCase {
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), true);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"), md
-                .getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), true);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"),
+            md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(1, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "TRUNK", "2.2"), dds[0]
-                .getDependencyRevisionId());
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "TRUNK", "2.2"),
+            dds[0].getDependencyRevisionId());
     }
 
+    @Test
     public void testReplaceBranch() throws Exception {
         IvyConfigure settings = new IvyConfigure();
         settings.setProject(project);
         settings.execute();
         // change the default branch to use
-        IvyAntSettings.getDefaultInstance(settings).getConfiguredIvyInstance(settings).getSettings().setDefaultBranch("BRANCH1");
-        
+        IvyAntSettings.getDefaultInstance(settings).getConfiguredIvyInstance(settings)
+                .getSettings().setDefaultBranch("BRANCH1");
+
         // resolve a module dependencies
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-latest.xml");
         IvyResolve res = new IvyResolve();
@@ -329,24 +346,30 @@ public class IvyDeliverTest extends TestCase {
         deliver.setDeliverpattern("build/test/deliver/ivy-[revision].xml");
         deliver.execute();
 
-        // should have done the ivy delivering, including setting the branch according to the 
+        // should have done the ivy delivering, including setting the branch according to the
         // configured default
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), true);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"), md
-                .getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), true);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"),
+            md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(1, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "BRANCH1", "2.2"), 
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "BRANCH1", "2.2"),
             dds[0].getDependencyRevisionId());
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "latest.integration"), 
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "latest.integration"),
             dds[0].getDynamicConstraintDependencyRevisionId());
     }
 
+    /**
+     * Test case for IVY-415.
+     *
+     * @throws Exception if something goes wrong
+     * @see <a href="https://issues.apache.org/jira/browse/IVY-415">IVY-415</a>
+     */
+    @Test
     public void testWithExtraAttributes() throws Exception {
-        // test case for IVY-415
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-latest-extra.xml");
         IvyResolve res = new IvyResolve();
         res.setValidate(false);
@@ -362,69 +385,116 @@ public class IvyDeliverTest extends TestCase {
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), false);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"), md
-                .getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), false);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"),
+            md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(1, dds.length);
-        Map extraAtt = new HashMap();
+        Map<String, String> extraAtt = new HashMap<>();
         extraAtt.put("myExtraAtt", "myValue");
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2", extraAtt), dds[0]
-                .getDependencyRevisionId());
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2", extraAtt),
+            dds[0].getDependencyRevisionId());
     }
 
+    @Test
     public void testWithDynEvicted() throws Exception {
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-dyn-evicted.xml");
         IvyResolve res = new IvyResolve();
         res.setValidate(false);
         res.setProject(project);
         res.execute();
-        
+
         deliver.setPubrevision("1.2");
         deliver.setDeliverpattern("build/test/deliver/ivy-[revision].xml");
         deliver.setValidate(false);
         deliver.execute();
-        
+
         // should have done the ivy delivering
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
-        assertTrue(deliveredIvyFile.exists()); 
+        assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-        new IvySettings(), deliveredIvyFile.toURL(), false);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"), 
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), false);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"),
             md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(2, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "1.1"), 
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2"),
             dds[0].getDependencyRevisionId());
+
+        IvyRetrieve ret = new IvyRetrieve();
+        ret.setProject(project);
+        ret.setPattern("build/test/retrieve/[artifact]-[revision].[ext]");
+        ret.execute();
+
+        File list = new File("build/test/retrieve");
+        String[] files = list.list();
+        HashSet<String> actualFileSet = new HashSet<>(Arrays.asList(files));
+        HashSet<String> expectedFileSet = new HashSet<>();
+        for (DependencyDescriptor dd : dds) {
+            String name = dd.getDependencyId().getName();
+            String rev = dd.getDependencyRevisionId().getRevision();
+            String ext = "jar";
+            String artifact = name + "-" + rev + "." + ext;
+            expectedFileSet.add(artifact);
+        }
+        assertEquals("Delivered Ivy descriptor inconsistent with retrieved artifacts",
+            expectedFileSet, actualFileSet);
     }
 
+    /**
+     * Test case for IVY-707.
+     *
+     * @throws Exception if something goes wrong
+     * @see <a href="https://issues.apache.org/jira/browse/IVY-707">IVY-707</a>
+     */
+    @Test
     public void testWithDynEvicted2() throws Exception {
         // same as previous but dynamic dependency is placed after the one causing the conflict
-        // test case for IVY-707
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-dyn-evicted2.xml");
         IvyResolve res = new IvyResolve();
         res.setValidate(false);
         res.setProject(project);
         res.execute();
-        
+
         deliver.setPubrevision("1.2");
         deliver.setDeliverpattern("build/test/deliver/ivy-[revision].xml");
         deliver.setValidate(false);
         deliver.execute();
-        
+
         // should have done the ivy delivering
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
-        assertTrue(deliveredIvyFile.exists()); 
+        assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-        new IvySettings(), deliveredIvyFile.toURL(), false);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"), 
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), false);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"),
             md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(2, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "1.1"), 
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.2"),
             dds[1].getDependencyRevisionId());
+
+        IvyRetrieve ret = new IvyRetrieve();
+        ret.setProject(project);
+        ret.setPattern("build/test/retrieve/[artifact]-[revision].[ext]");
+        ret.execute();
+
+        File list = new File("build/test/retrieve");
+        String[] files = list.list();
+        HashSet<String> actualFileSet = new HashSet<>(Arrays.asList(files));
+        HashSet<String> expectedFileSet = new HashSet<>();
+        for (DependencyDescriptor dd : dds) {
+            String name = dd.getDependencyId().getName();
+            String rev = dd.getDependencyRevisionId().getRevision();
+            String ext = "jar";
+            String artifact = name + "-" + rev + "." + ext;
+            expectedFileSet.add(artifact);
+        }
+        assertEquals("Delivered Ivy descriptor inconsistent with retrieved artifacts",
+            expectedFileSet, actualFileSet);
+        list.delete();
     }
 
+    @Test
     public void testReplaceImportedConfigurations() throws Exception {
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-import-confs.xml");
         IvyResolve res = new IvyResolve();
@@ -440,12 +510,13 @@ public class IvyDeliverTest extends TestCase {
         assertTrue(deliveredIvyFile.exists());
         String deliveredFileContent = FileUtil.readEntirely(new BufferedReader(new FileReader(
                 deliveredIvyFile)));
-        assertTrue("import not replaced: import can still be found in file", deliveredFileContent
-                .indexOf("import") == -1);
-        assertTrue("import not replaced: conf1 cannot be found in file", deliveredFileContent
-                .indexOf("conf1") != -1);
+        assertTrue("import not replaced: import can still be found in file",
+                !deliveredFileContent.contains("import"));
+        assertTrue("import not replaced: conf1 cannot be found in file",
+                deliveredFileContent.contains("conf1"));
     }
 
+    @Test
     public void testReplaceVariables() throws Exception {
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-with-variables.xml");
         IvyResolve res = new IvyResolve();
@@ -463,12 +534,13 @@ public class IvyDeliverTest extends TestCase {
         assertTrue(deliveredIvyFile.exists());
         String deliveredFileContent = FileUtil.readEntirely(new BufferedReader(new FileReader(
                 deliveredIvyFile)));
-        assertTrue("variable not replaced: myvar can still be found in file", deliveredFileContent
-                .indexOf("myvar") == -1);
-        assertTrue("variable not replaced: myvalue cannot be found in file", deliveredFileContent
-                .indexOf("myvalue") != -1);
+        assertTrue("variable not replaced: myvar can still be found in file",
+                !deliveredFileContent.contains("myvar"));
+        assertTrue("variable not replaced: myvalue cannot be found in file",
+                deliveredFileContent.contains("myvalue"));
     }
 
+    @Test
     public void testNoReplaceDynamicRev() throws Exception {
         project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-latest.xml");
         IvyResolve res = new IvyResolve();
@@ -484,15 +556,16 @@ public class IvyDeliverTest extends TestCase {
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), true);
-        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"), md
-                .getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), true);
+        assertEquals(ModuleRevisionId.newInstance("apache", "resolve-latest", "1.2"),
+            md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(1, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "latest.integration"), dds[0]
-                .getDependencyRevisionId());
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "latest.integration"),
+            dds[0].getDependencyRevisionId());
     }
 
+    @Test
     public void testDifferentRevisionsForSameModule() throws Exception {
         project.setProperty("ivy.dep.file",
             "test/java/org/apache/ivy/ant/ivy-different-revisions.xml");
@@ -508,16 +581,16 @@ public class IvyDeliverTest extends TestCase {
         File deliveredIvyFile = new File("build/test/deliver/ivy-1.2.xml");
         assertTrue(deliveredIvyFile.exists());
         ModuleDescriptor md = XmlModuleDescriptorParser.getInstance().parseDescriptor(
-            new IvySettings(), deliveredIvyFile.toURL(), true);
-        assertEquals(ModuleRevisionId.newInstance("apache", "different-revs", "1.2"), md
-                .getModuleRevisionId());
+            new IvySettings(), deliveredIvyFile.toURI().toURL(), true);
+        assertEquals(ModuleRevisionId.newInstance("apache", "different-revs", "1.2"),
+            md.getModuleRevisionId());
         DependencyDescriptor[] dds = md.getDependencies();
         assertEquals(3, dds.length);
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.0"), dds[0]
-                .getDependencyRevisionId());
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.1", "1.0"), dds[1]
-                .getDependencyRevisionId());
-        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "1.1"), dds[2]
-                .getDependencyRevisionId());
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "2.0"),
+            dds[0].getDependencyRevisionId());
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.1", "1.0"),
+            dds[1].getDependencyRevisionId());
+        assertEquals(ModuleRevisionId.newInstance("org1", "mod1.2", "1.1"),
+            dds[2].getDependencyRevisionId());
     }
 }
