@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,19 +17,24 @@
  */
 package org.apache.ivy.util.url;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
 import java.net.URL;
 import java.util.List;
 
-import junit.framework.TestCase;
+import org.junit.Test;
 
-public class ArtifactoryListingTest extends TestCase {
+public class ArtifactoryListingTest {
     // remote.test
-    
+
+    @Test
     public void testWicketListing() throws Exception {
         ApacheURLLister lister = new ApacheURLLister();
-        
-        List content = lister.listAll(new URL("http://repo.jfrog.org/artifactory/libs-releases-local/org/apache/wicket/wicket/"));
+
+        List<URL> content = lister.listAll(new URL(
+                "http://repo.jfrog.org/artifactory/libs-releases-local/org/apache/wicket/wicket/"));
         assertNotNull(content);
-        assertEquals(2, content.size());
+        assertEquals(3, content.size());
     }
 }
